# MongoDb Module

**For additional reference, please review the [source](https://github.com/Codeception/Codeception/tree/master/src/Codeception/Module/MongoDb.php)**
## Codeception\Module\MongoDb

* *Extends* `Codeception\Module`

Works with MongoDb database.

The most important function of this module is cleaning database before each test.
To have your database properly cleaned you should configure it to access the database.

In order to have your database populated with data you need a valid js file with data (of the same style which can be fed up to mongo binary)
File can be generated by RockMongo export command
Just put it in ``` tests/_data ``` dir (by default) and specify path to it in config.
Next time after database is cleared all your data will be restored from dump.
The DB preparation should as following:
- clean database
- system collection system.users should contain the user which will be authenticated while script performs DB operations

Connection is done by MongoDb driver, which is stored in Codeception\Lib\Driver namespace.
Check out the driver if you get problems loading dumps and cleaning databases.

## Status

* Maintainer: **judgedim**, **davert**
* Stability: **beta**
* Contact: codecept@davert.mail.ua

*Please review the code of non-stable modules and provide patches if you have issues.*

## Config

* dsn *required* - MongoDb DSN with the db name specified at the end of the host after slash
* user *required* - user to access database
* password *required* - password
* dump - path to database dump
* populate: true - should the dump be loaded before test suite is started.
* cleanup: true - should the dump be reloaded after each test

#### *public* dbh* `api` 
 * `var`




#### *public* driver* `var`  \Codeception\Lib\Driver\MongoDb

#### *public static* includeInheritedActionsBy setting it to false module wan't inherit methods of parent class.

 * `var`  bool
#### *public static* onlyActionsAllows to explicitly set what methods have this class.

 * `var`  array
#### *public static* excludeActionsAllows to explicitly exclude actions from module.

 * `var`  array
#### *public static* aliasesAllows to rename actions

 * `var`  array






### haveInCollection
#### *public* haveInCollection($collection, array $data)Inserts data into collection

``` php
$I->haveInCollection('users', array('name' => 'John', 'email' => 'john * `coltrane.com'));` 
$user_id = $I->haveInCollection('users', array('email' => 'john * `coltrane.com'));` 
```

 * `param`  $collection
 * `param`  array $data
### seeInCollection
#### *public* seeInCollection($collection, $criteria = null)Checks if collection contains an item.

``` php
<?php
$I->seeInCollection('users', array('name' => 'miles'));
```

 * `param`  $collection
 * `param`  array $criteria
### dontSeeInCollection
#### *public* dontSeeInCollection($collection, $criteria = null)Checks if collection doesn't contain an item.

``` php
<?php
$I->dontSeeInCollection('users', array('name' => 'miles'));
```

 * `param`  $collection
 * `param`  array $criteria
### grabFromCollection
#### *public* grabFromCollection($collection, $criteria = null)Grabs a data from collection

``` php
<?php
$cursor = $I->grabFromCollection('users', array('name' => 'miles'));
```

 * `param`  $collection
 * `param`  array $criteria
 * `return`  \MongoCursor




































